@@ -57,6 +57,7 @@ class Sync(threading.Thread):
     def __init__(self, cmd, pool, *vargs, **kwargs):
         super().__init__(*vargs, **kwargs)
         self.args = cmd
+        self.by_measurement = cmd.sync_by_measurement
         self.connections = cmd.sync
         self.auth = cmd.auth
         self.api_url = self.auth.api_url
@@ -112,7 +113,7 @@ class Sync(threading.Thread):
                 ms[pk]['last_update'] = parser.parse(mod['creation']).replace(tzinfo=datetime.timezone.utc)
                 if mod['action'] == 'delete' and pk in ms:
                     del ms[pk]
-        by_dcm_frame = defaultdict(list)
+        grouped = defaultdict(list)
         for m in ms.values():
             proto = self.protocol.get('measurements', {}).get(str(m.get('code_id')), {})
             if (proto.get('shouldDisplay')
@@ -120,8 +121,9 @@ class Sync(threading.Thread):
                     and m.get('used')
                     and m.get('dicom_id')
                     and m.get('plot_obj')):
-                by_dcm_frame[m['dicom_id'], m['frame']].append(m['id'])
-        for ms in by_dcm_frame.values():
+                k = (m['dicom_id'], m['frame'], *([m['id']] if self.by_measurement else []))
+                grouped[k].append(m['id'])
+        for ms in grouped.values():
             if 'PS' in self.modalities:
                 yield self.ps(ms)
             if 'SC' in self.modalities:
