@@ -505,6 +505,12 @@ def read_args():
         type=float,
         help='Delay between polls',
     )
+    parser.add_argument(
+        '--sync-by-measurement',
+        default=False,
+        action='store_true',
+        help='Will cause all PS/SC files to contain just one measurement each, instead of all for the frame',
+    )
     parser.add_argument(
         '--username',
         help='App username',
